#ifndef JSON_CONFIG_H
#define JSON_CONFIG_H

#include "Arduino.h"
#include "ArduinoJson.h"
#include "FS.h"


// --------------- Supported Sensors (Uncomment for Enable) -------------------
#define DHT_ON
#define BME280_ON
#define SHT21_ON
#define BH1750_ON
//#define PZEM_ON
//-----------------------------------------------------------------------------

#define DEBUG
#define DEBUG_JSON_CONFIG

#define RESET_BUTTON_ON   //Функционал сброса конфига по кнопке при загрузке модуля
//#define REBOOT_ON
#define NTP_ON

// ----------------- UART Settings ---------------------------------------------

//#define UART_ON
//#define DEBUG_ESP_UART
//#define CRC_ENABLE

#define DIGITAL_PINS 14   //Кол-во цифровых входов/выходов
#define ANALOG_PINS 6     //Кол-во цифровых входов/выходов
#define PARSE_CELLS 4     //Кол-во ячеек в массиве принимаемых данных
#define DATA_LENGTH 10    //Максимальный размер пакета данных без маркеров и CRC
//------------------------------------------------------------------------------

#define ESP_PINS 17
#define UP true 
#define DOWN false

enum WIFI_MODE_ENUM {AP, STA, AP_STA};
enum WIFI_PHY_MODE_ENUM {B, G, N};
enum WIFI_AUTH_ENUM {OPEN, WPA_PSK, WPA2_PSK, WPA_WPA2_PSK};

const String ConfigFileName = "/conf.json";

class JsonConf
{
  public:
    bool saveConfig();
    bool loadConfig();
    void deleteConfig();
    bool printConfig();

    char module_id                    [32] = "ESP8266"            ;
    char wifi_mode                    [2]  = "1"                  ;
    char wifi_phy_mode                [2]  = "2"                  ;
    char wifi_channel                 [3]  = "10"                 ;
    char wifi_auth                    [2]  = "2"                  ;
    char sta_ssid                     [32] = "*****"              ;
    char sta_pwd                      [32] = "*****"              ;
    char ap_pwd                       [32] = "Poiu0987"           ;
    char static_ip                    [16] = "192.0.4.222"        ;
    char static_gateway               [16] = "192.0.4.1"          ;
    char static_subnet                [16] = "255.255.255.0"      ;
    char ntp_server                   [32] = "europe.pool.ntp.org"; // NTP сервер желательно указать ip-адресом а не DNS именем.
    char my_time_zone                 [4]  = "+3"                 ;
    char mqtt_server                  [32] = "192.0.4.12"         ;
    char mqtt_port                    [6]  = "1883"               ;
    char mqtt_user                    [32] = "mqtt_user"          ;
    char mqtt_pwd                     [32] = "123456"             ;
    char mqtt_name                    [32] = "_BedM"              ;
    char publish_topic                [32] = "/stateSub/"         ;
    char subscribe_topic              [32] = "/statePub/"         ;
    char command_pub_topic            [32] = "/commandPub/"       ;
    char light_pin                    [3]  = "13"                 ;
    char lightoff_delay               [32] = "5"                  ;
    char lighton_lux                  [6]  = "10"                 ; // Значение в люксах, ниже которого будет включаться нагрузка
    char light_smooth                 [2]  = "0"                  ;
    char light2_pin                   [3]  = "12"                 ;
    char light2off_delay              [32] = "5"                  ;
    char light2on_lux                 [6]  = "10"                 ; // Значение в люксах, ниже которого будет включаться нагрузка
    char light2_smooth                [2]  = "0"                  ;
    char reset_pin                    [3]  = "2"                  ;
    char motion_pin                   [3]  = "14"                 ;
    char dht_pin                      [3] =  "2"                  ;
    char get_data_delay               [32] = "10"                 ;
    char publish_delay                [32] = "10"                 ;
    char subscribe_delay              [32] = "60"                 ;
    char motion_read_delay            [32] = "10"                 ;
    char reboot_delay                 [32] = "1800"               ;

    char uart_delay_analog_pin0       [32] = "none"               ;
    char uart_delay_analog_pin1       [32] = "none"               ;
    char uart_delay_analog_pin2       [32] = "none"               ;
    char uart_delay_analog_pin3       [32] = "none"               ;
    char uart_delay_analog_pin4       [32] = "none"               ;
    char uart_delay_analog_pin5       [32] = "none"               ;
    char green_light_on               [6]  = "8:00"               ;
    char green_light_off              [6]  = "22:00"              ;
    char green_light_pin              [3]  = "12"                 ;
    char green_humidity_threshold_up  [5]  = "800"                ;
    char green_humidity_threshold_down[5]  = "250"                ;
    char green_humidity_sensor_pin    [3]  = "20"                 ;
    char green_pump_pin               [3]  = "33"                 ;

    char static_ip_enable             [2]  = "0"                  ;
    char ntp_enable                   [2]  = "1"                  ;
    char mqtt_enable                  [2]  = "1"                  ;
    char dht_enable                   [2]  = "1"                  ;
    char bme280_enable                [2]  = "0"                  ;
    char sht21_enable                 [2]  = "0"                  ;
    char bh1750_enable                [2]  = "0"                  ;
    char motion_sensor_enable         [2]  = "0"                  ;
    char pzem_enable                  [2]  = "0"                  ;


  private:
};

#endif
